@@ -483,17 +483,19 @@ def secret():
 
 @secret.command("create", help="Create a new secret")
 @click.option("-b", "--base-profile", "base_profile", required=False)
+@click.option("-f", "--secret-file", "secret_file", required=False)
 @click.pass_obj
-def cli_secret_create(obj, base_profile):
+def cli_secret_create(obj, base_profile, secret_file):
     from suite_py.commands.secret import Secret
 
-    Secret(obj["project"], obj["config"], "create", base_profile).run()
+    Secret(obj["project"], obj["config"], "create", base_profile, secret_file).run()
 
 
 @secret.command("grant", help="Grant permissions to an existing secret")
 @click.option("-b", "--base-profile", "base_profile", required=False)
+@click.option("-f", "--secret-file", "secret_file", required=False)
 @click.pass_obj
-def cli_secret_grant(obj, base_profile):
+def cli_secret_grant(obj, base_profile, secret_file):
     from suite_py.commands.secret import Secret
 
-    Secret(obj["project"], obj["config"], "grant", base_profile).run()
+    Secret(obj["project"], obj["config"], "grant", base_profile, secret_file).run()
