@@ -11,7 +11,7 @@ from halo import Halo
 
 from suite_py.lib import logger
 
-
+# pylint: disable=too-many-public-methods
 class GitHandler:
     def __init__(self, repo, config):
         self._repo = repo
@@ -142,6 +142,20 @@ class GitHandler:
                 logger.error(f"Error during command execution: {e}")
                 sys.exit(-1)
 
+    def tag(self, tag, message):
+        with Halo(text=f"Tagging {self._repo}...", spinner="dots", color="magenta"):
+            try:
+                subprocess.run(
+                    ["git", "tag", "-a", tag, "-m", message],
+                    cwd=self._path,
+                    check=True,
+                    stdout=subprocess.DEVNULL,
+                    stderr=subprocess.DEVNULL,
+                )
+            except (CalledProcessError) as e:
+                logger.error(f"Error during command execution: {e}")
+                sys.exit(-1)
+
     def sync(self):
         self.fetch()
         self.checkout("master")
